{% extends "modeladmin/inspect.html" %}

{% block header %}
    {% include "wagtailadmin/shared/header_with_locale_selector.html" with title=view.get_page_title subtitle=view.get_page_subtitle icon=view.header_icon tabbed=True %}
{% endblock %}
